/* $Id: editable.gen_h,v 1.43 2000/02/13 02:22:09 kenelson Exp $ */

/* editable.h
 *
 * Copyright (C) 1998-1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/widget.h>
#include <gtk/gtkeditable.h>

namespace Gtk {
//: Abstract class for objects that user can edit.
class Editable : public Widget {


public:
  typedef Editable          CppObjectType;
  typedef GtkEditable            BaseObjectType;

public:
  //: Returns the underlaying gtk+ object.
  GtkEditable* gtkobj();
  const GtkEditable* gtkobj() const;

  //: Returns true if object is this type.
  static bool isA(Gtk::Object *object);

  virtual ~Editable();

private:

public:
  Editable();

    emitable signal void changed();

    signal void activate();

    emitable signal void insert_text(const gchar*,gint,gint*);

    emitable signal void delete_text(gint,gint);

    emitable signal void set_editable(gboolean);

    signal void move_cursor(gint,gint);

    signal void move_word(gint);

    signal void move_page(gint,gint);

    signal void move_to_row(gint);

    signal void move_to_column(gint);

    signal void kill_char(gint);

    signal void kill_word(gint);

    signal void kill_line(gint);

    emitable signal void cut_clipboard();

    emitable signal void copy_clipboard();

    emitable signal void paste_clipboard();

  //SIGNAL_SPEC("get_chars",vfunc,gchar* get_chars(gint,gint),gtk_editable_get_chars);




  void select_region(gint start,gint end);

  /* no function for 1.1, we'll use signal instead */

  gint get_position() const;


  string get_chars(gint start_pos,gint end_pos) const;


  void claim_selection(gboolean claim,guint32 time);


  void delete_selection();


  guint get_selection_start_pos() const { return gtkobj()->selection_start_pos; }
  guint get_selection_end_pos()   const { return gtkobj()->selection_end_pos; }
  bool  has_selection()           const { return gtkobj()->has_selection; }




protected:
  // impl functions
    virtual void changed_impl();
    virtual void activate_impl();
    virtual void insert_text_impl(const gchar* p0,gint p1,gint* p2);
    virtual void delete_text_impl(gint p0,gint p1);
    virtual void set_editable_impl(gboolean p0);
    virtual void move_cursor_impl(gint p0,gint p1);
    virtual void move_word_impl(gint p0);
    virtual void move_page_impl(gint p0,gint p1);
    virtual void move_to_row_impl(gint p0);
    virtual void move_to_column_impl(gint p0);
    virtual void kill_char_impl(gint p0);
    virtual void kill_word_impl(gint p0);
    virtual void kill_line_impl(gint p0);
    virtual void cut_clipboard_impl();
    virtual void copy_clipboard_impl();
    virtual void paste_clipboard_impl();

};


//+ PROPERTIES(Gtk_Editable)
//. name: current_pos
//. type: guint
//. get:
//. set:
//. desc:

//. name: selection_start_pos
//. type: guint
//. get:
//. set:
//. desc:

//. name: selection_end_pos
//. type: guint
//. get:
//. set:
//. desc:

//. name: has_selection
//. type: guint:1
//. get:
//. set:
//. desc:

//. name: editable
//. type: guint:1
//. get:
//. set:
//. desc:

//. name: ic
//. type: GdkIC*
//. get:
//. set:
//. desc:

//. name: ic_attr
//. type: GdkICAttr*
//. get:
//. set:
//. desc:

//. name: clipboard_text
//. type: string
//. get:
//. set:
//. desc:

}
