/* $Id: ruler.gen_h,v 1.30 2000/04/03 22:58:42 glaurent Exp $ */

/* ruler.h
 *
 * Copyright (C) 1998-1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/widget.h>
#include <gtk/gtkruler.h>
#include <gtk/gtkhruler.h>
#include <gtk/gtkvruler.h>


namespace Gtk {
//: Abstract Ruler
//- Ruler is an abstraction used as the base for Gtk_HRuler and
//- Gtk_VRuler.  Users should only instantiate those types.
class Ruler : public Widget {


public:
  typedef Ruler          CppObjectType;
  typedef GtkRuler            BaseObjectType;

public:
  //: Returns the underlaying gtk+ object.
  GtkRuler* gtkobj();
  const GtkRuler* gtkobj() const;

  //: Returns true if object is this type.
  static bool isA(Gtk::Object *object);

  virtual ~Ruler();

private:

public:




  //: Gets the metric of the ruler.
  GtkMetricType get_metric() const;

  //: Sets the desired metric of the ruler.  The possible choices are:
  //- <ul><li>GTK_PIXELS
  //- <li>GTK_INCHES
  //- <li>GTK_CENTIMETERS
  //- </ul>The default metric is GTK_PIXELS.

  void set_metric(GtkMetricType metric=GTK_PIXELS);



  gfloat get_range_lower() const;


  gfloat get_range_upper() const;

  //: sets the range of the ruler.
  //- <i>upper</i> and <i>lower</i> arguments denote the extents of the Ruler.
  //- <i>max_size</i> is the largest number displayed by the ruler.
  //- <i>position</i> gives the initial value of the ruler.
  //- Rulers do not have sane defaults so this function should always be called.



  void set_range(gfloat lower,gfloat upper,gfloat position,gfloat max_size);

  //: draw tick marks on the ruler

  void draw_ticks();

  //: draw a position indicator on the ruler

  void draw_pos();

protected:
  Ruler();



protected:
  // impl functions

};


//: Vertical Ruler
class VRuler : public Ruler {


public:
  typedef VRuler          CppObjectType;
  typedef GtkVRuler            BaseObjectType;

public:
  //: Returns the underlaying gtk+ object.
  GtkVRuler* gtkobj();
  const GtkVRuler* gtkobj() const;

  //: Returns true if object is this type.
  static bool isA(Gtk::Object *object);

  virtual ~VRuler();

private:

public:
  VRuler();





protected:
  // impl functions

};


//: Horizontal Ruler
class HRuler : public Ruler {


public:
  typedef HRuler          CppObjectType;
  typedef GtkHRuler            BaseObjectType;

public:
  //: Returns the underlaying gtk+ object.
  GtkHRuler* gtkobj();
  const GtkHRuler* gtkobj() const;

  //: Returns true if object is this type.
  static bool isA(Gtk::Object *object);

  virtual ~HRuler();

private:

public:
  HRuler();





protected:
  // impl functions

};


//+ PROPERTIES(Gtk_Ruler)
//. name: backing_store
//. type: GdkPixmap*
//. get:
//. set:
//. desc:

//. name: non_gr_exp_gc
//. type: GdkGC*
//. get:
//. set:
//. desc:

//. name: metric
//. type: GtkRulerMetric*
//. get:
//. set:
//. desc:

//. name: slider_size
//. type: gint
//. get:
//. set:
//. desc:

//. name: lower
//. type: gfloat
//. get:
//. set:
//. desc: The upper limit of the ruler (in points)

//. name: upper
//. type: gfloat
//. get:
//. set:
//. desc: The lower limit of the ruler

//. name: position
//. type: gfloat
//. get:
//. set:
//. desc: The position of the mark on the ruler

//. name: max_size
//. type: gfloat
//. get:
//. set:
//. desc: The maximum size of the ruler

}
